<!DOCTYPE html>
<html lang="ru">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Онлайн редактор кода с поддержкой PHP, JavaScript, CSS и HTML. Включает подсветку синтаксиса, древовидную структуру файлов и чат с AI.">
    <meta name="keywords" content="редактор кода, онлайн IDE, PHP редактор, JavaScript редактор, подсветка синтаксиса">
    <title>Редактор кода | Online IDE</title>
    
    <!-- jQuery должен быть первым! -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    
    <!-- CodeMirror и другие зависимости -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/codemirror.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/theme/dracula.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/theme/solarized.min.css" rel="stylesheet">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/codemirror.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/xml/xml.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/javascript/javascript.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/css/css.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/clike/clike.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/php/php.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/htmlmixed/htmlmixed.min.js"></script>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    
    <style>
        /* Основные переменные для тем */
        :root {
            --bg-primary: #f0f4f8;
            --bg-secondary: #e5eaf0;
            --text-primary: #1b2b3a;
            --text-secondary: #4a5d70;
            --border-color: rgba(148, 163, 184, 0.15);
            --accent-color: #4c6ef5;
            --tab-active: #ffffff;
            --tab-inactive: #e5eaf0;
            --chat-bg: #f0f4f8;
            --chat-border: rgba(148, 163, 184, 0.15);
            --chat-input-bg: #ffffff;
            --send-button-bg: #4c6ef5;
            --send-button-hover: #4055c8;
            --tree-hover: rgba(76, 110, 245, 0.08);
            --tree-selected: rgba(76, 110, 245, 0.12);
            --scrollbar-thumb: rgba(76, 110, 245, 0.3);
            --scrollbar-track: rgba(76, 110, 245, 0.05);
        }

        [data-theme="dark"] {
            --bg-primary: #111827;
            --bg-secondary: #1a2436;
            --text-primary: #e5eaf0;
            --text-secondary: #94a3b8;
            --border-color: rgba(148, 163, 184, 0.1);
            --accent-color: #5c7cff;
            --tab-active: #1a2436;
            --tab-inactive: #111827;
            --chat-bg: #1a2436;
            --chat-border: rgba(148, 163, 184, 0.1);
            --chat-input-bg: #111827;
            --send-button-bg: #5c7cff;
            --send-button-hover: #4c6ef5;
            --tree-hover: rgba(92, 124, 255, 0.08);
            --tree-selected: rgba(92, 124, 255, 0.12);
            --scrollbar-thumb: rgba(92, 124, 255, 0.3);
            --scrollbar-track: rgba(92, 124, 255, 0.05);
        }

        /* Базовые стили */
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, sans-serif;
            background-color: var(--bg-primary);
            color: var(--text-primary);
            height: 100vh;
            display: flex;
            flex-direction: column;
            overflow: hidden;
        }

        /* Скроллбар */
        ::-webkit-scrollbar {
            width: 8px;
            height: 8px;
        }

        ::-webkit-scrollbar-track {
            background: var(--scrollbar-track);
            border-radius: 4px;
        }

        ::-webkit-scrollbar-thumb {
            background: var(--scrollbar-thumb);
            border-radius: 4px;
        }

        ::-webkit-scrollbar-thumb:hover {
            background: var(--accent-color);
        }

        /* Основной контейнер */
        .container {
            display: flex;
            flex: 1;
            overflow: hidden;
        }

        /* Сайдбар */
        .sidebar {
            width: 310px;
            min-width: 310px;
            max-width: 800px;
            background-color: var(--bg-secondary);
            border-right: 1px solid var(--border-color);
            display: flex;
            flex-direction: column;
            position: relative;
        }

        /* Вертикальный резайзер */
        .sidebar-resizer {
            width: 4px;
            height: 100%;
            position: absolute;
            right: -2px;
            top: 0;
            background-color: var(--border-color);
            cursor: col-resize;
            z-index: 10;
        }

        .sidebar-resizer:hover {
            background-color: var(--accent-color);
        }

        .sidebar-resizer::after {
            content: '';
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            height: 30px;
            width: 2px;
            background-color: var(--text-secondary);
            border-radius: 1px;
        }

        /* Проводник файлов */
        .file-explorer {
            padding: 0.5rem;
            overflow-y: auto;
            background-color: var(--bg-primary);
            flex: 1;
            min-height: 100px;
        }

        /* Стили дерева файлов */
        .file-tree {
            list-style: none;
            font-size: 0.9rem;
        }

        .file-tree li {
            padding: 0.3rem 0.5rem;
            cursor: pointer;
            display: flex;
            align-items: center;
            gap: 0.5rem;
            border-radius: 4px;
            transition: background-color 0.2s ease;
        }

        .file-tree li:hover {
            background-color: var(--tree-hover);
        }

        .file-tree li.selected {
            background-color: var(--tree-selected);
        }

        .file-tree li i {
            width: 16px;
            text-align: center;
        }

        .file-tree .folder {
            color: #6b8aaf;
        }

        .file-tree .folder-content {
            margin-left: 1.5rem;
            display: block;
        }

        .file-tree .folder-content.collapsed {
            display: none;
        }

        .file-tree .folder i.fa-chevron-right {
            transition: transform 0.2s ease;
        }

        .file-tree .folder.expanded i.fa-chevron-right {
            transform: rotate(90deg);
        }

        /* Резайзер для чата */
        .chat-resizer {
            height: 4px;
            background-color: var(--border-color);
            cursor: row-resize;
            position: relative;
        }

        .chat-resizer:hover {
            background-color: var(--accent-color);
        }

        .chat-resizer::after {
            content: '';
            position: absolute;
            left: 50%;
            top: 50%;
            transform: translate(-50%, -50%);
            width: 30px;
            height: 2px;
            background-color: var(--text-secondary);
            border-radius: 1px;
        }

        /* Чат с AI */
        .ai-chat {
            height: 300px;
            min-height: 150px;
            border-top: 1px solid var(--border-color);
            padding: 1rem;
            display: flex;
            flex-direction: column;
            background-color: var(--chat-bg);
            position: relative;
        }

        .chat-messages {
            flex: 1;
            overflow-y: auto;
            margin-bottom: 1rem;
            padding: 0.5rem;
            font-size: 0.875rem;
        }

        .chat-message {
            margin-bottom: 0.8rem;
            padding: 0.8rem;
            border-radius: 8px;
            background-color: var(--chat-input-bg);
            box-shadow: 0 1px 2px rgba(0,0,0,0.05);
            border: 1px solid var(--border-color);
            display: flex;
            align-items: flex-start;
            gap: 0.5rem;
            max-width: 85%;
        }

        .chat-message.user-message {
            margin-left: auto;
            background-color: var(--accent-color);
            color: white;
        }

        .chat-message.ai-message {
            margin-right: auto;
        }

        .chat-input {
            display: flex;
            gap: 0.5rem;
            padding: 0.5rem;
            background-color: var(--chat-input-bg);
            border-radius: 8px;
            border: 1px solid var(--chat-border);
            box-shadow: 0 1px 2px rgba(0,0,0,0.05);
        }

        .chat-input input {
            flex: 1;
            padding: 0.8rem;
            border: none;
            border-radius: 4px;
            background-color: transparent;
            color: var(--text-primary);
            font-size: 0.875rem;
        }

        .chat-input input:focus {
            outline: none;
        }

        .send-button {
            width: 40px;
            height: 40px;
            background-color: var(--send-button-bg);
            color: white;
            border: none;
            border-radius: 50%;
            cursor: pointer;
            transition: all 0.3s ease;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .send-button:hover {
            background-color: var(--send-button-hover);
            transform: scale(1.05);
        }

        /* Редактор */
        .editor-container {
            flex: 1;
            display: flex;
            flex-direction: column;
            overflow: hidden;
        }

        /* Вкладки */
        .tabs {
            display: flex;
            justify-content: space-between;
            background-color: var(--bg-secondary);
            border-bottom: 1px solid var(--border-color);
            padding: 0.5rem 0.5rem 0 0.5rem;
        }

        .tabs-container {
            display: flex;
            flex: 1;
            overflow-x: auto;
            margin-right: 0.5rem;
            flex-wrap: wrap;
            gap: 0.25rem;
        }

        .tab {
            padding: 0.6rem 1rem;
            background-color: var(--tab-inactive);
            border: none;
            border-right: 1px solid var(--border-color);
            color: var(--text-primary);
            cursor: pointer;
            display: flex;
            align-items: center;
            gap: 0.5rem;
            transition: all 0.2s ease;
            white-space: nowrap;
            margin-bottom: 0.25rem;
            border-radius: 4px 4px 0 0;
        }

        .tab.active {
            background-color: var(--tab-active);
            border-top: 2px solid var(--accent-color);
        }

        .tab:hover {
            background-color: var(--tab-active);
        }

        /* Переключатель темы */
        .theme-toggle {
            padding: 0.6rem;
            border: 1px solid var(--border-color);
            background: transparent;
            color: var(--text-primary);
            cursor: pointer;
            border-radius: 8px;
            display: flex;
            align-items: center;
            justify-content: center;
            transition: all 0.2s ease;
            margin-left: 0.5rem;
            width: 40px;
            height: 40px;
        }

        .theme-toggle:hover {
            background-color: var(--bg-primary);
            transform: translateY(-1px);
        }

        .theme-toggle:active {
            transform: translateY(0);
        }

        /* Иконки темы */
        [data-theme="light"] .theme-toggle .fa-sun {
            display: none;
        }

        [data-theme="light"] .theme-toggle .fa-moon {
            display: block;
        }

        [data-theme="dark"] .theme-toggle .fa-sun {
            display: block;
        }

        [data-theme="dark"] .theme-toggle .fa-moon {
            display: none;
        }

        /* Адаптивность */
        @media (max-width: 768px) {
            .sidebar {
                position: absolute;
                height: 100%;
                transform: translateX(-100%);
                transition: transform 0.3s ease;
                z-index: 1000;
            }

            .sidebar.show {
                transform: translateX(0);
            }
        }

        /* CodeMirror кастомизация */
        .CodeMirror {
            height: 100% !important;
            font-family: 'Fira Code', monospace;
            font-size: 14px;
            line-height: 1.5;
        }

        .CodeMirror-gutters {
            border-right: 1px solid var(--border-color);
        }

        .CodeMirror-linenumber {
            color: var(--text-secondary);
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="sidebar" id="sidebar">
            <div class="file-explorer">
                <ul class="file-tree" id="fileTree"></ul>
            </div>
            <div class="chat-resizer" id="chatResizer"></div>
            <div class="ai-chat">
                <div class="chat-messages" id="chatMessages"></div>
                <div class="chat-input">
                    <input type="text" placeholder="Задайте вопрос AI..." id="chatInput">
                    <button class="send-button" id="sendMessage">
                        <i class="fas fa-paper-plane"></i>
                    </button>
                </div>
            </div>
            <div class="sidebar-resizer" id="sidebarResizer"></div>
        </div>
        
        <div class="editor-container">
            <div class="tabs" id="tabs">
                <div class="tabs-container"></div>
                <button class="theme-toggle" id="themeToggle" title="Переключить тему">
                    <i class="far fa-sun"></i>
                    <i class="far fa-moon"></i>
                </button>
            </div>
            <div id="editor"></div>
        </div>
    </div>

    <script>
        // Начальные файлы
        const initialFiles = {
            'src/index.html': '123'
        };

        let editor;
        let currentFile = '';
        const fileTree = $('#fileTree');
        const tabs = $('.tabs-container');
        
        // Инициализация редактора
        function initEditor() {
            editor = CodeMirror(document.getElementById('editor'), {
                mode: 'javascript',
                theme: localStorage.getItem('theme') === 'dark' ? 'dracula' : 'solarized light',
                lineNumbers: true,
                autoCloseBrackets: true,
                matchBrackets: true,
                indentUnit: 4,
                tabSize: 4,
                lineWrapping: true,
                foldGutter: true,
                gutters: ['CodeMirror-linenumbers', 'CodeMirror-foldgutter'],
                extraKeys: {
                    'Ctrl-Space': 'autocomplete'
                }
            });

            editor.on('change', () => {
                if (currentFile) {
                    initialFiles[currentFile] = editor.getValue();
                }
            });
        }

        // Определение типа файла для иконки
        function getFileIcon(filename) {
            if (filename.endsWith('.html')) return '<i class="fab fa-html5 html"></i>';
            if (filename.endsWith('.css')) return '<i class="fab fa-css3-alt css"></i>';
            if (filename.endsWith('.js')) return '<i class="fab fa-js js"></i>';
            if (filename.endsWith('.php')) return '<i class="fab fa-php"></i>';
            return '<i class="fas fa-file-code"></i>';
        }

        // Определение режима редактора по расширению файла
        function getFileMode(filename) {
            if (filename.endsWith('.php')) return {name: 'php', startOpen: true};
            if (filename.endsWith('.html')) return 'htmlmixed';
            if (filename.endsWith('.js')) return 'javascript';
            if (filename.endsWith('.css')) return 'css';
            return 'text/plain';
        }

        // Открытие файла
        function openFile(filename) {
            currentFile = filename;
            const content = initialFiles[filename];
            editor.setValue(content);
            editor.setOption('mode', getFileMode(filename));
            
            $('.tab').removeClass('active');
            $(`.tab[data-path="${filename}"]`).addClass('active');
            
            $('.file-tree li').removeClass('selected');
            $(`.file-tree li[data-path="${filename}"]`).addClass('selected');

            // Создаем вкладку, если её нет
            if (!$(`.tab[data-path="${filename}"]`).length) {
                createTab(filename);
            }
        }

        // Создание вкладки
        function createTab(filename) {
            const icon = getFileIcon(filename);
            const tab = $('<button>')
                .addClass('tab')
                .attr('data-path', filename)
                .html(`${icon}${filename.split('/').pop()}`)
                .click(() => openFile(filename));
            
            if (filename === currentFile) {
                tab.addClass('active');
            }
            
            tabs.append(tab);
        }

        // Создание дерева файлов
        function createFileTree() {
            const structure = {};
            
            // Создаем структуру папок
            Object.keys(initialFiles).forEach(path => {
                const parts = path.split('/');
                let current = structure;
                
                parts.forEach((part, index) => {
                    if (index === parts.length - 1) {
                        current[part] = { type: 'file', path: path };
                    } else {
                        current[part] = current[part] || { type: 'folder', children: {} };
                        current = current[part].children;
                    }
                });
            });

            // Рекурсивная функция для отрисовки дерева
            function renderTree(obj, parent = fileTree) {
                Object.entries(obj)
                    .sort(([keyA, valueA], [keyB, valueB]) => {
                        if (valueA.type !== valueB.type) {
                            return valueA.type === 'folder' ? -1 : 1;
                        }
                        return keyA.localeCompare(keyB);
                    })
                    .forEach(([name, value]) => {
                        const li = $('<li>');
                        
                        if (value.type === 'folder') {
                            const folderContent = $('<ul>').addClass('folder-content');
                            const chevron = $('<i>').addClass('fas fa-chevron-right');
                            const folderIcon = $('<i>').addClass('fas fa-folder folder');
                            
                            li.addClass('folder')
                                .append(chevron)
                                .append(folderIcon)
                                .append(name)
                                .click(function(e) {
                                    e.stopPropagation();
                                    $(this).toggleClass('expanded');
                                    folderIcon.toggleClass('fa-folder fa-folder-open');
                                    folderContent.toggleClass('collapsed');
                                });
                            
                            parent.append(li);
                            parent.append(folderContent);
                            renderTree(value.children, folderContent);
                            
                            // По умолчанию папки развернуты
                            li.addClass('expanded');
                            folderIcon.addClass('fa-folder-open');
                        } else {
                            li.html(getFileIcon(name) + name)
                                .attr('data-path', value.path)
                                .click(() => openFile(value.path));
                            
                            parent.append(li);
                        }
                    });
            }
            
            fileTree.empty();
            renderTree(structure);
        }

        // Инициализация чата
        function initChat() {
            const input = $('#chatInput');
            const messages = $('#chatMessages');
            const sendButton = $('#sendMessage');

            function sendMessage() {
                const text = input.val().trim();
                if (!text) return;

                const userMessage = $('<div>').addClass('chat-message user-message');
                const userIcon = $('<i>').addClass('fas fa-user');
                const userContent = $('<div>').addClass('message-content').text(text);
                userMessage.append(userIcon, userContent);
                messages.append(userMessage);
                input.val('');
                
                $.ajax({
                    method: "POST",
                    url: "aicoder.php",
                    data: { ai: text }
                })
                    .done(function(msg) { 
                        reciveMessage(msg);
                    });
                
                messages.scrollTop(messages[0].scrollHeight);
            }

            function reciveMessage(text) {
                const aiMessage = $('<div>').addClass('chat-message ai-message');
                const aiIcon = $('<i>').addClass('fas fa-robot');
                const aiContent = $('<div>').addClass('message-content')
                    .text(text);
                aiMessage.append(aiIcon, aiContent);

                messages.append(aiMessage);
                
                messages.scrollTop(messages[0].scrollHeight);
            }

            sendButton.click(sendMessage);
            input.keypress(e => {
                if (e.which === 13) sendMessage();
            });
        }

        // Инициализация переключателя темы
        function initThemeToggle() {
            const toggle = $('#themeToggle');
            const theme = localStorage.getItem('theme') || 'light';
            
            document.documentElement.setAttribute('data-theme', theme);
            if (editor) {
                editor.setOption('theme', theme === 'dark' ? 'dracula' : 'solarized light');
            }
            
            toggle.click(() => {
                const currentTheme = document.documentElement.getAttribute('data-theme');
                const newTheme = currentTheme === 'dark' ? 'light' : 'dark';
                
                localStorage.setItem('theme', newTheme);
                document.documentElement.setAttribute('data-theme', newTheme);
                
                if (editor) {
                    editor.setOption('theme', newTheme === 'dark' ? 'dracula' : 'solarized light');
                }
            });
        }

        // Инициализация резайзера чата
        function initChatResizer() {
            const resizer = document.getElementById('chatResizer');
            const chat = document.querySelector('.ai-chat');
            const fileExplorer = document.querySelector('.file-explorer');
            let startY;
            let startHeight;
            let startExplorerHeight;

            function startResize(e) {
                startY = e.clientY;
                startHeight = parseInt(getComputedStyle(chat).height, 10);
                startExplorerHeight = parseInt(getComputedStyle(fileExplorer).height, 10);
                
                document.documentElement.style.cursor = 'row-resize';
                document.addEventListener('mousemove', resize);
                document.addEventListener('mouseup', stopResize);
            }

            function resize(e) {
                const diff = startY - e.clientY;
                const newChatHeight = Math.max(150, startHeight + diff);
                const newExplorerHeight = Math.max(100, startExplorerHeight - diff);
                
                chat.style.height = `${newChatHeight}px`;
                fileExplorer.style.height = `${newExplorerHeight}px`;
            }

            function stopResize() {
                document.documentElement.style.cursor = '';
                document.removeEventListener('mousemove', resize);
                document.removeEventListener('mouseup', stopResize);
            }

            resizer.addEventListener('mousedown', startResize);
        }

        // Инициализация резайзера сайдбара
        function initSidebarResizer() {
            const resizer = document.getElementById('sidebarResizer');
            const sidebar = document.getElementById('sidebar');
            let startX;
            let startWidth;

            function startResize(e) {
                startX = e.clientX;
                startWidth = parseInt(getComputedStyle(sidebar).width, 10);
                
                document.documentElement.style.cursor = 'col-resize';
                document.addEventListener('mousemove', resize);
                document.addEventListener('mouseup', stopResize);
                
                // Предотвращаем выделение текста при resize
                document.addEventListener('selectstart', preventSelect);
            }

            function resize(e) {
                const width = startWidth + (e.clientX - startX);
                // Ограничиваем минимальную и максимальную ширину
                if (width >= 310 && width <= 800) {
                    sidebar.style.width = `${width}px`;
                }
            }

            function stopResize() {
                document.documentElement.style.cursor = '';
                document.removeEventListener('mousemove', resize);
                document.removeEventListener('mouseup', stopResize);
                document.removeEventListener('selectstart', preventSelect);
            }

            function preventSelect(e) {
                e.preventDefault();
            }

            resizer.addEventListener('mousedown', startResize);
        }

        // Инициализация приложения
        $(document).ready(() => {
            initEditor();
            createFileTree();
            initThemeToggle();
            initChat();
            initChatResizer();
            initSidebarResizer();
            
            // Открываем первый файл по умолчанию
            const firstFile = Object.keys(initialFiles)[0];
            if (firstFile) {
                openFile(firstFile);
            }
        });
    </script>
</body>
</html>