
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Web Code Editor</title>
    
    <!-- CodeMirror -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/codemirror.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/theme/dracula.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/theme/eclipse.min.css" rel="stylesheet">
    
    <!-- Bootstrap Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.1/font/bootstrap-icons.css" rel="stylesheet">
    
    <style>
        /* Стилизация скролл-бара */
        ::-webkit-scrollbar {
            width: 8px;
            height: 8px;
        }

        ::-webkit-scrollbar-track {
            background: transparent;
        }

        .dark-theme ::-webkit-scrollbar-thumb {
            background: var(--dark-border);
            border-radius: 4px;
        }

        .dark-theme ::-webkit-scrollbar-thumb:hover {
            background: var(--dark-hover);
        }

        .light-theme ::-webkit-scrollbar-thumb {
            background: var(--light-border);
            border-radius: 4px;
        }

        .light-theme ::-webkit-scrollbar-thumb:hover {
            background: var(--light-hover);
        }

        :root {
            --dark-bg: #1a1b26;
            --dark-secondary: #1f2335;
            --dark-border: #2c3549;
            --dark-accent: #7aa2f7;
            --dark-hover: #3b4261;
            --light-bg: #f5f6f9;
            --light-secondary: #ebeef5;
            --light-border: #dce0ec;
            --light-accent: #5c7cdc;
            --light-hover: #e4e7f3;
        }

        body {
            margin: 0;
            padding: 0;
            height: 100vh;
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, sans-serif;
        }

        body.dark-theme {
            background: var(--dark-bg);
            color: #c0caf5;
        }

        body.light-theme {
            background: var(--light-bg);
            color: #1a1b26;
        }

        .main-container {
            display: flex;
            height: 100vh;
        }

        .left-panel {
            display: flex;
            flex-direction: column;
            border-right: 1px solid var(--dark-border);
        }

        .dark-theme .left-panel {
            border-color: var(--dark-border);
            background: var(--dark-secondary);
        }

        .light-theme .left-panel {
            border-color: var(--light-border);
            background: var(--light-secondary);
        }

        .file-tree {
            flex: 1;
            padding: 10px;
            overflow-y: auto;
        }

        .chat-panel {
            height: 300px;
            border-top: 1px solid var(--dark-border);
            padding: 10px;
            display: flex;
            flex-direction: column;
        }

        .dark-theme .chat-panel {
            border-color: var(--dark-border);
        }

        .light-theme .chat-panel {
            border-color: var(--light-border);
        }

        .editor-container {
            flex: 1;
            display: flex;
            flex-direction: column;
        }

        .tabs {
            display: flex;
            background: var(--dark-secondary);
            border-bottom: 1px solid var(--dark-border);
            justify-content: space-between;
            align-items: center;
            padding-right: 10px;
        }

        .tabs-left {
            display: flex;
        }

        .dark-theme .tabs {
            background: var(--dark-secondary);
            border-color: var(--dark-border);
        }

        .light-theme .tabs {
            background: var(--light-secondary);
            border-color: var(--light-border);
        }

        .tab {
            padding: 8px 20px;
            cursor: pointer;
            border-right: 1px solid var(--dark-border);
            user-select: none;
        }

        .tab.active {
            background: var(--dark-bg);
            color: var(--dark-accent);
        }

        .light-theme .tab.active {
            background: var(--light-bg);
            color: var(--light-accent);
        }

        .theme-toggle {
            cursor: pointer;
            padding: 5px 10px;
            border-radius: 4px;
            background: transparent;
            border: 1px solid var(--dark-border);
            color: inherit;
        }
        .CodeMirror {
            height: 100% !important;
        }

        .file-tree ul {
            list-style: none;
            padding-left: 20px;
        }

        .file-tree > ul {
            padding-left: 0;
        }

        .file-item {
            cursor: pointer;
            padding: 3px 0;
        }

        .file-item i {
            margin-right: 5px;
        }

        .chat-messages {
            flex: 1;
            overflow-y: auto;
            padding: 10px;
            font-size: 0.9rem;
        }

        .chat-messages > div {
            margin-bottom: 12px;
            display: flex;
            align-items: flex-start;
            gap: 8px;
        }

        .chat-messages > div > i {
            font-size: 1.2rem;
            margin-top: 2px;
        }

        .message-content {
            background: var(--dark-secondary);
            padding: 8px 12px;
            border-radius: 12px;
            max-width: 85%;
            word-wrap: break-word;
        }

        .dark-theme .message-content {
            background: var(--dark-secondary);
        }

        .light-theme .message-content {
            background: var(--light-secondary);
        }

        .chat-messages > div.user-message {
            flex-direction: row-reverse;
        }

        .chat-messages > div.user-message .message-content {
            background: var(--dark-accent);
            color: #ffffff;
        }

        .light-theme .chat-messages > div.user-message .message-content {
            background: var(--light-accent);
        }

        .chat-input {
            display: flex;
            gap: 8px;
            margin-top: 10px;
            padding: 0 10px;
        }

        .chat-input input {
            flex: 1;
            padding: 8px 12px;
            border-radius: 20px;
            border: 1px solid var(--dark-border);
            background: var(--dark-secondary);
            color: inherit;
            font-size: 0.9rem;
        }

        .dark-theme .chat-input input {
            background: var(--dark-secondary);
            border-color: var(--dark-border);
            color: inherit;
        }

        .light-theme .chat-input input {
            background: var(--light-secondary);
            border-color: var(--light-border);
            color: inherit;
        }

        .chat-input .send-button {
            background: transparent;
            border: none;
            color: inherit;
            cursor: pointer;
            padding: 0 8px;
        }

        .chat-input .send-button i {
            font-size: 1.2rem;
        }

        /* Стили для разделителей */
        .gutter {
            background-color: var(--dark-border);
            background-repeat: no-repeat;
            background-position: 50%;
        }

        .gutter.gutter-horizontal {
            cursor: col-resize;
            width: 1px;
        }

        .gutter.gutter-vertical {
            cursor: row-resize;
            height: 1px;
        }

        .dark-theme .file-item:hover {
            background: var(--dark-hover);
        }

        .light-theme .file-item:hover {
            background: var(--light-hover);
        }
    </style>
</head>
<body class="dark-theme">
    <div class="main-container">
        <div class="left-panel">
            <div class="file-tree">
                <ul>
                    <li class="file-item"><i class="bi bi-folder-fill"></i>src
                        <ul>
                            <li class="file-item" data-file="game.php"><i class="bi bi-file-earmark-code"></i>game.php</li>
                            <li class="file-item" data-file="script.js"><i class="bi bi-file-earmark-code"></i>script.js</li>
                            <li class="file-item" data-file="styles.css"><i class="bi bi-file-earmark-code"></i>styles.css</li>
                        </ul>
                    </li>
                </ul>
            </div>
            <div class="chat-panel">
                <div class="chat-messages"></div>
                <div class="chat-input">
                    <input type="text" placeholder="Ask AI...">
                    <button class="send-button"><i class="bi bi-send"></i></button> </div>
            </div>
        </div>
        <div class="editor-container">
            <div class="tabs">
                <div class="tabs-left"></div>
                <button class="theme-toggle">
                    <i class="bi bi-sun-fill"></i>
                </button>
            </div>
            <div id="editor"></div>
        </div>
    </div>

    <!-- Dependencies -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/split.js/1.6.5/split.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/codemirror.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/xml/xml.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/javascript/javascript.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/css/css.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/php/php.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/clike/clike.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/htmlmixed/htmlmixed.min.js"></script>
    
    <script>
        $(document).ready(function() {
            // Example files content
            const files = {
                'game.php': `<?php
// Simple Number Guessing Game
session_start();

if (!isset($_SESSION['number'])) {
    $_SESSION['number'] = rand(1, 100);
    $_SESSION['attempts'] = 0;
}

$message = '';
if (isset($_POST['guess'])) {
    $_SESSION['attempts']++;
    $guess = (int)$_POST['guess'];
    
    if ($guess === $_SESSION['number']) {
        $message = "Congratulations! You got it in {$_SESSION['attempts']} attempts!";
        session_destroy();
    } elseif ($guess < $_SESSION['number']) {
        $message = "Too low! Try again.";
    } else {
        $message = "Too high! Try again.";
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Number Guessing Game</title>
</head>
<body>
    <h1>Guess the number between 1 and 100</h1>
    <?php if ($message): ?>
        <p><?php echo $message; ?></p>
    <?php endif; ?>
    <form method="post">
        <input type="number" name="guess" required>
        <button type="submit">Guess</button>
    </form>
</body>
</html>`,
                'script.js': `// Utility functions
function calculateFactorial(n) {
    if (n === 0 || n === 1) return 1;
    return n * calculateFactorial(n - 1);
}

function isPalindrome(str) {
    str = str.toLowerCase().replace(/[^a-z0-9]/g, '');
    return str === str.split('').reverse().join('');
}

function debounce(func, wait) {
    let timeout;
    return function executedFunction(...args) {
        const later = () => {
            clearTimeout(timeout);
            func(...args);
        };
        clearTimeout(timeout);
        timeout = setTimeout(later, wait);
    };
}
`,
                'styles.css': `/* Main styles */
:root {
    --primary-color: #007bff;
    --secondary-color: #6c757d;
    --success-color: #28a745;
    --border-radius: 4px;
}

body {
    font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
    line-height: 1.6;
    margin: 0;
    padding: 20px;
}

.container {
    max-width: 1200px;
    margin: 0 auto;
    padding: 0 15px;
}

.btn {
    display: inline-block;
    padding: 8px 16px;
    border-radius: var(--border-radius);
    border: none;
    cursor: pointer;
    transition: background-color 0.3s;
}

.btn-primary {
    background-color: var(--primary-color);
    color: white;
}

.btn-secondary {
    background-color: var(--secondary-color);
    color: white;
}
`
            };

            // Initialize Split.js
            Split(['.left-panel', '.editor-container'], {
                sizes: [20, 80],
                minSize: 200,
                gutterSize: 1,
                onDragEnd: function(sizes) {
                    localStorage.setItem('panelSizes', JSON.stringify(sizes));
                }
            });

            Split(['.file-tree', '.chat-panel'], {
                direction: 'vertical',
                sizes: [70, 30],
                gutterSize: 1,
                onDragEnd: function(sizes) {
                    localStorage.setItem('verticalSizes', JSON.stringify(sizes));
                }
            });

            // Initialize CodeMirror with proper PHP mode
            let editor = CodeMirror(document.getElementById('editor'), {
                mode: 'application/x-httpd-php',
                theme: 'dracula',
                lineNumbers: true,
                autoCloseBrackets: true,
                matchBrackets: true,
                indentUnit: 4,
                tabSize: 4,
                lineWrapping: true,
                extraKeys: {"Ctrl-Space": "autocomplete"}
            });

            // Theme management
            const theme = localStorage.getItem('theme') || 'dark';
            $('body').addClass(theme + '-theme');
            editor.setOption('theme', theme === 'dark' ? 'dracula' : 'eclipse');

            $('.theme-toggle').click(function() {
                const currentTheme = $('body').hasClass('dark-theme') ? 'dark' : 'light';
                const newTheme = currentTheme === 'dark' ? 'light' : 'dark';
                
                $('body').removeClass(currentTheme + '-theme').addClass(newTheme + '-theme');
                editor.setOption('theme', newTheme === 'dark' ? 'dracula' : 'eclipse');
                localStorage.setItem('theme', newTheme);
            });

            // Tab management
            let openFiles = [];
            
            function addTab(filename) {
                if (!openFiles.includes(filename)) {
                    openFiles.push(filename);
                    const $tab = $('<div class="tab">')
                        .text(filename)
                        .data('file', filename)
                        .appendTo('.tabs-left');

                    if (openFiles.length === 1) {
                        $tab.addClass('active');
                        editor.setValue(files[filename]);
                        setEditorMode(filename);
                    }
                }

                $('.tab').removeClass('active');
                $(`.tab[data-file="${filename}"]`).addClass('active');
                editor.setValue(files[filename]);
                setEditorMode(filename);
            }

            function setEditorMode(filename) {
                const ext = filename.split('.').pop();
                const modes = {
                    'php': 'application/x-httpd-php',
                    'js': 'javascript',
                    'css': 'css'
                };
                editor.setOption('mode', modes[ext] || 'text/plain');
            }

            // File tree interaction
            $('.file-item').click(function(e) {
                e.stopPropagation(); // Предотвращаем всплытие события
                const $this = $(this);

                // Если элемент содержит вложенный список (папка)
                if ($this.children('ul').length) {
                    $this.children('ul').slideToggle();
                    // Изменяем иконку папки
                    const $icon = $this.children('i').first();
                    if ($icon.hasClass('bi-folder-fill')) {
                        $icon.removeClass('bi-folder-fill').addClass('bi-folder2-open');
                    } else {
                        $icon.removeClass('bi-folder2-open').addClass('bi-folder-fill');
                    }
                } else if ($this.data('file')) {
                    // Если это файл, открываем его в редакторе
                    const filename = $this.data('file');
                    addTab(filename);
                }
            });

            // Tab interaction
            $(document).on('click', '.tab', function() {
                $('.tab').removeClass('active');
                $(this).addClass('active');
                const filename = $(this).data('file');
                editor.setValue(files[filename]);
                setEditorMode(filename);
            });

            // Load initial files
            ['game.php', 'script.js', 'styles.css'].forEach(filename => addTab(filename));

            // Restore panel sizes
            const savedPanelSizes = localStorage.getItem('panelSizes');
            if (savedPanelSizes) {
                const sizes = JSON.parse(savedPanelSizes);
                Split(['.left-panel', '.editor-container'], {
                    sizes: sizes,
                    minSize: 200,
                    gutterSize: 1
                });
            }

            // Simple AI chat functionality
            $('.chat-input input').keypress(function(e) {
                if (e.which === 13) {
                    const message = $(this).val();
                    if (message.trim()) {
                        $('.chat-messages').append(`
                            <div class="user-message">
                                <i class="bi bi-person-circle"></i>
                                <div class="message-content">${message}</div>
                            </div>
                        `);
                        let aiResponse;
                        if (message.toLowerCase().includes('привет')) {
                            aiResponse = 'Здравствуйте! Я AI-ассистент этого редактора кода. Чем могу помочь?';
                        } else if (message.toLowerCase().includes('синтаксис')) {
                            aiResponse = 'В редакторе поддерживается подсветка синтаксиса для PHP, JavaScript и CSS. Для PHP используется режим application/x-httpd-php.';
                        } else if (message.toLowerCase().includes('тема')) {
                            aiResponse = 'Вы можете переключить тему оформления с помощью кнопки в правом верхнем углу. Доступны светлая и темная темы.';
                        } else {
                            aiResponse = 'Я могу помочь вам с вопросами по использованию редактора. Например, спросите меня о подсветке синтаксиса или смене темы оформления.';
                        }
                        $('.chat-messages').append(`
                            <div>
                                <i class="bi bi-robot"></i>
                                <div class="message-content">${aiResponse}</div>
                            </div>
                        `);
                        $(this).val('');
                        $('.chat-messages').scrollTop($('.chat-messages')[0].scrollHeight);
                    }
                }
            });

            // Send button click handler
            $('.chat-input .send-button').click(function() {
                const input = $('.chat-input input');
                const message = input.val();
                if (message.trim()) {
                    $('.chat-messages').append(`
                        <div class="user-message">
                            <i class="bi bi-person-circle"></i>
                            <div class="message-content">${message}</div>
                        </div>
                    `);
                    let aiResponse;
                    if (message.toLowerCase().includes('привет')) {
                        aiResponse = 'Здравствуйте! Я AI-ассистент этого редактора кода. Чем могу помочь?';
                    } else if (message.toLowerCase().includes('синтаксис')) {
                        aiResponse = 'В редакторе поддерживается подсветка синтаксиса для PHP, JavaScript и CSS. Для PHP используется режим application/x-httpd-php.';
                    } else if (message.toLowerCase().includes('тема')) {
                        aiResponse = 'Вы можете переключить тему оформления с помощью кнопки в правом верхнем углу. Доступны светлая и темная темы.';
                    } else {
                        aiResponse = 'Я могу помочь вам с вопросами по использованию редактора. Например, спросите меня о подсветке синтаксиса или смене темы оформления.';
                    }
                    $('.chat-messages').append(`
                        <div>
                            <i class="bi bi-robot"></i>
                            <div class="message-content">${aiResponse}</div>
                        </div>
                    `);
                    input.val('');
                    $('.chat-messages').scrollTop($('.chat-messages')[0].scrollHeight);
                }
            });
        });
    </script>
</body>
</html>