<!DOCTYPE html>
<html lang="ru">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Админ-панель | Монетизатор</title>
    <link href="https://fonts.googleapis.com/css2?family=Montserrat:wght@400;500;600;700&display=swap" rel="stylesheet">
    <style>
        :root {
            --primary-color: #ffd700;
            --secondary-color: #ffa500;
            --background-color: #0a0a0a;
            --sidebar-bg: #1a1a1a;
            --text-color: #ffffff;
            --border-color: #333333;
            --card-bg: rgba(17, 17, 17, 0.8);
            --hover-color: #ffe44d;
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Montserrat', sans-serif;
        }

        body {
            background-color: var(--background-color);
            color: var(--text-color);
            min-height: 100vh;
            background-image: 
                linear-gradient(to bottom, rgba(0,0,0,0.85), rgba(0,0,0,0.95)),
                url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100"><circle cx="50" cy="50" r="40" fill="%23ffd700" opacity="0.15"/></svg>');
            background-size: 200px 200px;
        }

        .container {
            display: flex;
            min-height: 100vh;
        }

        /* Стили боковой панели */
        .sidebar {
            width: 250px;
            background: linear-gradient(145deg, #222222, var(--sidebar-bg));
            border-right: 2px solid rgba(255, 215, 0, 0.15);
            padding: 1.5rem;
            transition: all 0.3s ease;
            backdrop-filter: blur(10px);
            box-shadow: 
                inset -1px 0 0 rgba(255, 215, 0, 0.1),
                5px 0 15px rgba(0, 0, 0, 0.5);
        }

        .sidebar-header {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            margin-bottom: 2rem;
        }

        .sidebar-header svg {
            fill: none;
            stroke: var(--primary-color);
        }

        .sidebar-header h2 {
            background: linear-gradient(45deg, var(--primary-color), var(--secondary-color));
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
            font-size: 1.25rem;
            text-transform: uppercase;
            font-weight: 700;
            letter-spacing: 0.5px;
            text-shadow: 0 0 20px rgba(255, 215, 0, 0.5);
        }

        .nav-links {
            display: flex;
            flex-direction: column;
            gap: 0.5rem;
        }

        .nav-link {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            padding: 0.75rem 1rem;
            color: var(--text-color);
            text-decoration: none;
            border-radius: 0.5rem;
            transition: all 0.3s ease;
            font-weight: 500;
        }

        .nav-link svg {
            stroke: currentColor;
            transition: all 0.3s ease;
        }

        .nav-link:hover, .nav-link.active {
            background: linear-gradient(45deg, rgba(255, 215, 0, 0.1), rgba(255, 165, 0, 0.1));
            color: var(--primary-color);
            box-shadow: 0 0 15px rgba(255, 215, 0, 0.2);
        }

        /* Стили основного контента */
        .main-content {
            flex: 1;
            padding: 2rem;
            overflow-y: auto;
            background: linear-gradient(165deg, var(--background-color), rgba(0, 0, 0, 1));
            box-shadow: inset 5px 0 15px rgba(0, 0, 0, 0.8);
        }

        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 2rem;
        }

        .header h1 {
            background: linear-gradient(45deg, var(--primary-color), var(--secondary-color));
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
            font-size: 2rem;
            text-transform: uppercase;
            font-weight: 700;
            letter-spacing: 1px;
            text-shadow: 0 0 20px rgba(255, 215, 0, 0.3);
        }

        .btn {
            background: linear-gradient(45deg, var(--primary-color), var(--secondary-color));
            color: var(--background-color);
            border: none;
            padding: 0.75rem 1.5rem;
            border-radius: 0.5rem;
            font-weight: 600;
            cursor: pointer;
            transition: all 0.3s ease;
            text-transform: uppercase;
            box-shadow: 0 0 20px rgba(255, 215, 0, 0.3);
            letter-spacing: 0.5px;
        }

        .btn:hover {
            background: linear-gradient(45deg, var(--hover-color), #ffb52e);
            transform: translateY(-2px);
            box-shadow: 0 0 30px rgba(255, 215, 0, 0.4);
        }

        .stats-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(240px, 1fr));
            gap: 1.5rem;
            margin-bottom: 2rem;
        }

        .stat-card {
             background: linear-gradient(145deg, var(--sidebar-bg), rgba(26, 26, 26, 0.85));
            padding: 1.5rem;
            border-radius: 0.5rem;
            border: 1px solid rgba(255, 215, 0, 0.1);
            backdrop-filter: blur(10px);
            transition: all 0.3s ease;
        }

        .stat-card:hover {
            border-color: rgba(255, 215, 0, 0.2);
            transform: translateY(-2px);
            box-shadow: 0 0 20px rgba(255, 215, 0, 0.1);
        }

        .stat-card h3 {
            color: var(--text-color);
            font-size: 0.875rem;
            margin-bottom: 0.5rem;
            text-transform: uppercase;
            letter-spacing: 0.5px;
            opacity: 0.8;
        }

        .stat-card .value {
            background: linear-gradient(45deg, var(--primary-color), var(--secondary-color));
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
            font-size: 1.75rem;
            font-weight: 700;
            margin-bottom: 0.25rem;
        }

        .stat-card .description {
            color: rgba(255, 255, 255, 0.6);
            font-size: 0.875rem;
            margin-top: 0.5rem;
        }

        /* Стили таблицы */
        .table-container {
            background: linear-gradient(145deg, rgba(17, 17, 17, 0.95), rgba(17, 17, 17, 0.85));
            border-radius: 0.5rem;
            border: 1px solid rgba(255, 215, 0, 0.1);
            overflow-x: auto;
            backdrop-filter: blur(10px);
        }

        table {
            width: 100%;
            border-collapse: collapse;
        }

        th, td {
            padding: 1rem;
            text-align: left;
            border-bottom: 1px solid rgba(255, 215, 0, 0.1);
        }

        th {
            background-color: rgba(0, 0, 0, 0.3);
            font-weight: 600;
            color: var(--primary-color);
            text-transform: uppercase;
            letter-spacing: 0.5px;
            font-size: 0.875rem;
        }

        td {
            color: rgba(255, 255, 255, 0.8);
        }

        tr:hover td {
            background-color: rgba(255, 215, 0, 0.05);
        }

        /* Стили для мобильных устройств */
        .mobile-menu-toggle {
            display: none;
            background: none;
            border: none;
            color: var(--text-color);
            cursor: pointer;
            padding: 0.5rem;
        }

        @media (max-width: 768px) {
            .mobile-menu-toggle {
                display: block;
            }

            .sidebar {
                position: fixed;
                left: -250px;
                height: 100vh;
                z-index: 1000;
            }

            .sidebar.active {
                left: 0;
            }

            .main-content {
                padding: 1rem;
            }

            .stats-grid {
                grid-template-columns: 1fr;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <aside class="sidebar">
            <div class="sidebar-header">
                <svg width="32" height="32" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2">
                    <path d="M12 2L2 7L12 12L22 7L12 2Z" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round"/>
                    <path d="M2 17L12 22L22 17" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round"/>
                    <path d="M2 12L12 17L22 12" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round"/>
                </svg>
                <h2>Монетизатор</h2>
            </div>
            <nav class="nav-links">
                <a href="#" class="nav-link active">
                    <svg width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2">
                        <rect x="3" y="3" width="18" height="18" rx="2" />
                        <path d="M3 9H21" />
                        <path d="M9 21V9" />
                    </svg>
                    Дашборд
                </a>
                <a href="#" class="nav-link">
                    <svg width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2">
                        <path d="M20 21V19C20 17.9391 19.5786 16.9217 18.8284 16.1716C18.0783 15.4214 17.0609 15 16 15H8C6.93913 15 5.92172 15.4214 5.17157 16.1716C4.42143 16.9217 4 17.9391 4 19V21" />
                        <circle cx="12" cy="7" r="4" />
                    </svg>
                    Пользователи
                </a>
                <a href="#" class="nav-link">
                    <svg width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2">
                        <path d="M12 2L2 7L12 12L22 7L12 2Z" />
                        <path d="M2 17L12 22L22 17" />
                        <path d="M2 12L12 17L22 12" />
                    </svg>
                    Игры
                </a>
                <a href="#" class="nav-link">
                    <svg width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2">
                        <circle cx="12" cy="12" r="3" />
                        <path d="M19.4 15a1.65 1.65 0 0 0 .33 1.82l.06.06a2 2 0 0 1 0 2.83 2 2 0 0 1-2.83 0l-.06-.06a1.65 1.65 0 0 0-1.82-.33 1.65 1.65 0 0 0-1 1.51V21a2 2 0 0 1-2 2 2 2 0 0 1-2-2v-.09A1.65 1.65 0 0 0 9 19.4a1.65 1.65 0 0 0-1.82.33l-.06.06a2 2 0 0 1-2.83 0 2 2 0 0 1 0-2.83l.06-.06a1.65 1.65 0 0 0 .33-1.82 1.65 1.65 0 0 0-1.51-1H3a2 2 0 0 1-2-2 2 2 0 0 1 2-2h.09A1.65 1.65 0 0 0 4.6 9a1.65 1.65 0 0 0-.33-1.82l-.06-.06a2 2 0 0 1 0-2.83 2 2 0 0 1 2.83 0l.06.06a1.65 1.65 0 0 0 1.82.33H9a1.65 1.65 0 0 0 1-1.51V3a2 2 0 0 1 2-2 2 2 0 0 1 2 2v.09a1.65 1.65 0 0 0 1 1.51 1.65 1.65 0 0 0 1.82-.33l.06-.06a2 2 0 0 1 2.83 0 2 2 0 0 1 0 2.83l-.06.06a1.65 1.65 0 0 0-.33 1.82V9a1.65 1.65 0 0 0 1.51 1H21a2 2 0 0 1 2 2 2 2 0 0 1-2 2h-.09a1.65 1.65 0 0 0-1.51 1z" />
                    </svg>
                    Настройки
                </a>
            </nav>
        </aside>

        <main class="main-content">
            <button class="mobile-menu-toggle">
                <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2">
                    <path d="M3 12H21" />
                    <path d="M3 6H21" />
                    <path d="M3 18H21" />
                </svg>
            </button>

            <div class="header">
                <h1>Панель управления</h1>
                <button class="btn">Добавить игру</button>
            </div>

            <div class="stats-grid">
                <div class="stat-card">
                    <h3>Всего пользователей</h3>
                    <div class="value">1,234</div>
                    <div class="description">+180 за последний месяц</div>
                </div>
                <div class="stat-card">
                    <h3>Активные игры</h3>
                    <div class="value">45</div>
                    <div class="description">8 игр в процессе</div>
                </div>
                <div class="stat-card">
                    <h3>Конверсия</h3>
                    <div class="value">12.5%</div>
                    <div class="description">+2.1% к прошлой неделе</div>
                </div>
                <div class="stat-card">
                    <h3>Выручка</h3>
                    <div class="value">₽456,789</div>
                    <div class="description">+15% к прошлому месяцу</div>
                </div>
            </div>

            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>Пользователь</th>
                            <th>Игра</th>
                            <th>Статус</th>
                            <th>Дата</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Иван Петров</td>
                            <td>Монетизатор PRO</td>
                            <td>Активна</td>
                            <td>01.02.2025</td>
                        </tr>
                        <tr>
                            <td>Мария Сидорова</td>
                            <td>Монетизатор Старт</td>
                            <td>Завершена</td>
                            <td>31.01.2025</td>
                        </tr>
                        <tr>
                            <td>Алексей Иванов</td>
                            <td>Монетизатор PRO</td>
                            <td>В процессе</td>
                            <td>30.01.2025</td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </main>
    </div>

    <script>
        // Функциональность мобильного меню
        const menuToggle = document.querySelector('.mobile-menu-toggle');
        const sidebar = document.querySelector('.sidebar');

        menuToggle.addEventListener('click', () => {
            sidebar.classList.toggle('active');
        });

        // Закрытие бокового меню при клике вне его области на мобильных устройствах
        document.addEventListener('click', (e) => {
            if (window.innerWidth <= 768 && 
                !sidebar.contains(e.target) && 
                !menuToggle.contains(e.target)) {
                sidebar.classList.remove('active');
            }
        });
    </script>
</body>
</html>