<!DOCTYPE html>
<html lang="ru">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Монетизатор - Панель управления</title>
    <meta name="description" content="Панель управления для мониторинга и управления монетизацией игр">
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap" rel="stylesheet">
    <script src="https://unpkg.com/feather-icons"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <style>
        :root {
            --accent: #D4AF37;
            --accent-hover: #BF9F30;
            --bg-primary: #0F0F0F;
            --bg-secondary: #1A1A1A;
            --text-primary: #ffffff;
            --text-secondary: #9CA3AF;
            --border-color: rgba(212, 175, 55, 0.2);
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Inter', sans-serif;
        }

        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
            min-height: 100vh;
        }

        .sidebar {
            position: fixed;
            top: 0;
            left: 0;
            height: 100%;
            width: 250px;
            background-color: var(--bg-secondary);
            border-right: 1px solid var(--border-color);
            padding: 1.5rem;
            transition: transform 0.3s ease;
        }

        .sidebar h1 {
            color: var(--accent);
            font-size: 1.5rem;
            font-weight: bold;
            margin-bottom: 2rem;
        }

        .nav-item {
            display: flex;
            align-items: center;
            padding: 0.75rem 1rem;
            color: var(--text-primary);
            text-decoration: none;
            border-radius: 8px;
            margin-bottom: 0.5rem;
            transition: all 0.2s ease;
            gap: 12px;
        }

        .nav-item i {
            color: var(--accent);
            width: 20px;
            height: 20px;
            flex-shrink: 0;
            display: inline-flex;
            align-items: center;
            justify-content: center;
        }

        .nav-item:hover {
            background-color: rgba(212, 175, 55, 0.1);
        }

        .nav-item.active {
            background-color: var(--accent);
        }

        .nav-item.active i {
            color: var(--bg-primary);
        }

        .main-content {
            margin-left: 250px;
            padding: 0;
        }

        .header {
            background-color: var(--bg-secondary);
            border-bottom: 1px solid var(--border-color);
            padding: 1rem 2rem;
            margin-bottom: 2rem;
        }

        .header-content {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .user-info {
            display: flex;
            align-items: center;
            gap: 1rem;
        }

        .user-info img {
            width: 40px;
            height: 40px;
            border-radius: 50%;
            border: 2px solid var(--accent);
        }

        .user-name {
            font-weight: 500;
            color: var(--text-primary);
        }

        .user-role {
            color: var(--text-secondary);
            font-size: 0.875rem;
        }

        .header-actions {
            display: flex;
            align-items: center;
            gap: 1rem;
        }

        .add-game-btn {
            background: linear-gradient(180deg, var(--accent) 0%, var(--accent-hover) 100%);
            color: var(--bg-primary);
            padding: 0.75rem 1.5rem;
            border-radius: 8px;
            border: none;
            font-weight: 500;
            cursor: pointer;
            display: flex;
            align-items: center;
            gap: 0.5rem;
            transition: all 0.3s ease;
        }

        .add-game-btn:hover {
            background: linear-gradient(180deg, var(--accent-hover) 0%, var(--accent) 100%);
            transform: translateY(-1px);
        }

        .theme-toggle {
            background: none;
            border: 1px solid var(--border-color);
            color: var(--accent);
            width: 40px;
            height: 40px;
            border-radius: 8px;
            cursor: pointer;
            display: flex;
            align-items: center;
            justify-content: center;
            transition: all 0.3s ease;
        }

        .theme-toggle:hover {
            background-color: rgba(212, 175, 55, 0.1);
        }

        [data-theme="light"] {
            --bg-primary: #f8f9fa;
            --bg-secondary: #ffffff;
            --text-primary: #1a1a1a;
            --text-secondary: #6c757d;
            --border-color: rgba(0, 0, 0, 0.1);
        }

        .menu-toggle {
            display: none;
            position: fixed;
            top: 1rem;
            left: 1rem;
            z-index: 100;
            background-color: var(--accent);
            color: var(--bg-primary);
            border: none;
            padding: 0.5rem;
            border-radius: 8px;
            cursor: pointer;
        }

        @media (max-width: 768px) {
            .menu-toggle {
                display: block;
            }

            .sidebar {
                transform: translateX(-100%);
                z-index: 50;
            }

            .sidebar.active {
                transform: translateX(0);
            }

            .main-content {
                margin-left: 0;
            }

            .header {
                padding: 1rem;
            }

            .header-content {
                flex-direction: column;
                gap: 1rem;
            }

            .header-actions {
                width: 100%;
                justify-content: space-between;
            }

            .add-game-btn {
                flex: 1;
                justify-content: center;
            }
        }

        .stats-card {
            background-color: rgba(26, 26, 26, 0.5);
            padding: 1.5rem;
            border-radius: 12px;
            border: 1px solid rgba(255, 255, 255, 0.1);
        }

        .stats-title {
            color: #9CA3AF;
            font-size: 0.875rem;
            text-transform: uppercase;
            font-weight: 500;
            margin-bottom: 0.5rem;
        }

        .stats-value {
            color: var(--accent);
            font-size: 2rem;
            font-weight: 700;
            margin-bottom: 0.5rem;
        }

        .stats-change {
            color: #9CA3AF;
            font-size: 0.875rem;
        }

        .stats-change-positive {
            color: #22c55e;
        }
    </style>
</head>
<body>
    <button class="menu-toggle" id="menuToggle">
        <i data-feather="menu"></i>
    </button>

    <aside class="sidebar" id="sidebar">
        <h1>МОНЕТИЗАТОР</h1>
        <nav>
            <a href="#" class="nav-item active">
                <i data-feather="bar-chart-2"></i>
                Дашборд
            </a>
            <a href="#" class="nav-item">
                <i data-feather="users"></i>
                Пользователи
            </a>
            <a href="#" class="nav-item">
                <i data-feather="package"></i>
                Продукты
            </a>
            <a href="#" class="nav-item">
                <i data-feather="dollar-sign"></i>
                Транзакции
            </a>
            <a href="#" class="nav-item">
                <i data-feather="settings"></i>
                Настройки
            </a>
        </nav>
    </aside>

    <main class="main-content">
        <header class="header">
            <div class="header-content">
                <div class="user-info">
                    <img src="https://images.unsplash.com/photo-1472099645785-5658abf4ff4e?ixlib=rb-1.2.1&auto=format&fit=facearea&facepad=2&w=256&h=256&q=80" alt="Аватар пользователя">
                    <div>
                        <div class="user-name">Александр Иванов</div>
                        <div class="user-role">Администратор</div>
                    </div>
                </div>
                <div class="header-actions">
                    <button class="add-game-btn">
                        <i data-feather="plus-circle"></i>
                        Добавить игру
                    </button>
                    <button class="theme-toggle" id="themeToggle">
                        <i data-feather="sun"></i>
                    </button>
                </div>
            </div>
        </header>

        <div style="padding: 2rem;">
            <div style="display: grid; grid-template-columns: repeat(auto-fit, minmax(240px, 1fr)); gap: 1.5rem; margin-bottom: 2rem;">
                <div class="stats-card">
                    <h4 class="stats-title">ВСЕГО ПОЛЬЗОВАТЕЛЕЙ</h4>
                    <div class="stats-value">1,234</div>
                    <div class="stats-change">+180 за последний месяц</div>
                </div>

                <div class="stats-card">
                    <h4 class="stats-title">АКТИВНЫЕ ИГРЫ</h4>
                    <div class="stats-value">45</div>
                    <div class="stats-change">8 игр в процессе</div>
                </div>

                <div class="stats-card">
                    <h4 class="stats-title">КОНВЕРСИЯ</h4>
                    <div class="stats-value">12.5%</div>
                    <div class="stats-change stats-change-positive">+2.1% к прошлой неделе</div>
                </div>

                <div class="stats-card">
                    <h4 class="stats-title">ВЫРУЧКА</h4>
                    <div class="stats-value">₽456,789</div>
                    <div class="stats-change stats-change-positive">+15% к прошлому месяцу</div>
                </div>
            </div>

            <div style="background-color: var(--bg-secondary); border-radius: 8px; border: 1px solid var(--border-color);">
                <div style="padding: 1.5rem; border-bottom: 1px solid var(--border-color);">
                    <h3 style="font-size: 1.125rem; font-weight: 600; color: var(--accent);">Последние игры</h3>
                </div>
                <div style="overflow-x: auto;">
                    <table style="width: 100%; border-collapse: collapse;">
                        <thead>
                            <tr style="background-color: var(--bg-primary);">
                                <th style="text-align: left; padding: 1rem; font-size: 0.75rem; text-transform: uppercase; color: var(--accent);">Город</th>
                                <th style="text-align: left; padding: 1rem; font-size: 0.75rem; text-transform: uppercase; color: var(--accent);">Дата игры</th>
                                <th style="text-align: left; padding: 1rem; font-size: 0.75rem; text-transform: uppercase; color: var(--accent);">Игроки</th>
                                <th style="text-align: left; padding: 1rem; font-size: 0.75rem; text-transform: uppercase; color: var(--accent);">Зрители</th>
                                <th style="text-align: left; padding: 1rem; font-size: 0.75rem; text-transform: uppercase; color: var(--accent);">Доход</th>
                                <th style="text-align: left; padding: 1rem; font-size: 0.75rem; text-transform: uppercase; color: var(--accent);">Статус</th>
                                <th style="text-align: center; padding: 1rem; font-size: 0.75rem; text-transform: uppercase; color: var(--accent);">Действие</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr style="border-top: 1px solid var(--border-color); transition: background-color 0.2s;">
                                <td style="padding: 1rem;">Москва</td>
                                <td style="padding: 1rem;">24.03.2024 19:30</td>
                                <td style="padding: 1rem;">
                                    <span style="color: var(--accent);">12</span>
                                    <span style="color: var(--text-secondary);">/</span>
                                    <span style="color: var(--text-secondary);">15</span>
                                </td>
                                <td style="padding: 1rem;">234</td>
                                <td style="padding: 1rem;">₽45,600</td>
                                <td style="padding: 1rem;">
                                    <span style="display: inline-block; padding: 0.25rem 0.75rem; background-color: #dcfce7; color: #166534; border-radius: 9999px; font-size: 0.75rem; font-weight: 600;">
                                        Завершена
                                    </span>
                                </td>
                                <td style="padding: 1rem; text-align: center;">
                                    <button style="background: linear-gradient(180deg, var(--accent) 0%, var(--accent-hover) 100%); color: var(--bg-primary); padding: 0.5rem 1rem; border: none; border-radius: 6px; font-weight: 500; cursor: pointer; transition: transform 0.2s;">
                                        ПОДРОБНО
                                    </button>
                                </td>
                            </tr>
                            <tr style="border-top: 1px solid var(--border-color); transition: background-color 0.2s;">
                                <td style="padding: 1rem;">Санкт-Петербург</td>
                                <td style="padding: 1rem;">23.03.2024 15:00</td>
                                <td style="padding: 1rem;">
                                    <span style="color: var(--accent);">8</span>
                                    <span style="color: var(--text-secondary);">/</span>
                                    <span style="color: var(--text-secondary);">10</span>
                                </td>
                                <td style="padding: 1rem;">156</td>
                                <td style="padding: 1rem;">₽32,800</td>
                                <td style="padding: 1rem;">
                                    <span style="display: inline-block; padding: 0.25rem 0.75rem; background-color: #dcfce7; color: #166534; border-radius: 9999px; font-size: 0.75rem; font-weight: 600;">
                                        Завершена
                                    </span>
                                </td>
                                <td style="padding: 1rem; text-align: center;">
                                    <button style="background: linear-gradient(180deg, var(--accent) 0%, var(--accent-hover) 100%); color: var(--bg-primary); padding: 0.5rem 1rem; border: none; border-radius: 6px; font-weight: 500; cursor: pointer; transition: transform 0.2s;">
                                        ПОДРОБНО
                                    </button>
                                </td>
                            </tr>
                            <style>
                                tr:hover {
                                    background-color: rgba(212, 175, 55, 0.05);
                                }
                                button:hover {
                                    transform: translateY(-1px);
                                }
                            </style>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </main>

    <script>
        // Инициализация иконок
        feather.replace();

        // Мобильное меню
        $('#menuToggle').on('click', function() {
            $('#sidebar').toggleClass('active');
        });

        // Закрытие меню при клике вне его на мобильных
        $(document).on('click', function(event) {
            if (window.innerWidth <= 768) {
                if (!$(event.target).closest('#sidebar, #menuToggle').length) {
                    $('#sidebar').removeClass('active');
                }
            }
        });  

        // Переключение темы
        $('#themeToggle').on('click', function() {
            const $body = $('body');
            const $icon = $(this).find('i');
            
            if ($body.attr('data-theme') === 'light') {
                $body.removeAttr('data-theme');
                $icon.attr('data-feather', 'sun');
            } else {
                $body.attr('data-theme', 'light');
                $icon.attr('data-feather', 'moon');
            }
            
            feather.replace();
        });

        // Обработка изменения размера окна
        $(window).on('resize', function() {
            if (window.innerWidth > 768) {
                $('#sidebar').removeClass('active');
            }
        });
    </script>
</body>
</html>