// Инициализация иконок
feather.replace();

// Мобильное меню
$('#menuToggle').on('click', function() {
    $('#sidebar').toggleClass('active');
});

// Закрытие меню при клике вне его на мобильных
$(document).on('click', function(event) {
    if (window.innerWidth <= 768) {
        if (!$(event.target).closest('#sidebar, #menuToggle').length) {
            $('#sidebar').removeClass('active');
        }
    }
});

// Переключение темы
$('#themeToggle').on('click', function() {
    const $body = $('body');
    const $icon = $(this).find('i');
    
    if ($body.attr('data-theme') === 'light') {
        $body.removeAttr('data-theme');
        $icon.attr('data-feather', 'sun');
    } else {
        $body.attr('data-theme', 'light');
        $icon.attr('data-feather', 'moon');
    }
    
    feather.replace();
});

// Привязка кнопки открытия модального окна
$('.add-game-btn').on('click', function() {
    openModal();
});

// Функции модального окна
function openModal() {
    const $modal = $('#addGameModal');
    $modal.addClass('active');
    
    // Устанавливаем минимальную дату в поле выбора даты (сегодня)
    const today = new Date();
    const minDateTime = today.toISOString().slice(0, 16);
    $('#gameDate').attr('min', minDateTime);
    
    // Устанавливаем фокус на первое поле после анимации
    setTimeout(() => {
        $('#gameCity').focus();
    }, 300);
    
    feather.replace();
}

function closeModal() {
    const $modal = $('#addGameModal');
    $modal.removeClass('active');
    setTimeout(() => {
        $('#addGameForm')[0].reset();
    }, 300);
}

// Обработка отправки формы
$('#addGameForm').on('submit', function(e) {
    e.preventDefault();
    
    // Собираем данные формы
    const gameData = {
        city: $('#gameCity').val(),
        date: $('#gameDate').val(),
        maxPlayers: $('#maxPlayers').val(),
        maxSpectators: $('#maxSpectators').val(),
        playerPrice: $('#playerPrice').val(),
        spectatorPrice: $('#spectatorPrice').val(),
        description: $('#gameDescription').val()
    };
    
    console.log('Новая игра:', gameData);
    closeModal();
    alert('Игра успешно создана!');
});

// Обработка изменения размера окна
$(window).on('resize', function() {
    if (window.innerWidth > 768) {
        $('#sidebar').removeClass('active');
    }
});

// Функции для отображения отзывов
function showReviews(userId) {
    alert('Здесь будут показаны отзывы о пользователе ' + userId);
}

function showGameReviews(gameId) {
    alert('Здесь будут показаны отзывы об игре ' + gameId);
}


// Функция для отображения деталей игры
        function showGameDetails(gameId) {
            const $modal = $('#gameDetailsModal');
            const $content = $modal.find('.game-details-content');
            
            // Показываем модальное окно
            $modal.addClass('active');
            
            // Здесь должен быть запрос к серверу за данными
            // Для демонстрации используем моковые данные
            const mockData = {
                city: "Москва",
                dateTime: "2024-03-24T19:30:00",
                status: "completed",
                currentPlayers: 12,
                maxPlayers: 15,
                currentSpectators: 234,
                maxSpectators: 300,
                revenue: 45600,
                players: [
                    {
                        id: "p1",
                        name: "Михаил Петров",
                        avatar: "https://images.unsplash.com/photo-1500648767791-00dcc994a43e",
                        phone: "+7 (900) 123-45-67",
                        telegram: "@mikhail",
                        hasReview: false
                    },
                    {
                        id: "p2",
                        name: "Анна Смирнова",
                        avatar: "https://images.unsplash.com/photo-1494790108377-be9c29b29330",
                        phone: "+7 (900) 123-45-68",
                        telegram: "@anna",
                        hasReview: true
                    }
                ],
                spectators: [
                    {
                        id: "s1",
                        name: "Дмитрий Иванов",
                        avatar: "https://images.unsplash.com/photo-1472099645785-5658abf4ff4e",
                        ticket: "VIP"
                    },
                    {
                        id: "s2",
                        name: "Екатерина Новикова",
                        avatar: "https://images.unsplash.com/photo-1534528741775-53994a69daeb",
                        ticket: "Стандарт"
                    }
                ]
            };

            // Обновляем содержимое модального окна
            $content.html(`
                <div class="game-details">
                    <div class="details-section">
                        <h3>Основная информация</h3>
                        <div class="details-grid">
                            <div class="detail-item">
                                <div class="detail-label">Город</div>
                                <div class="detail-value">${mockData.city}</div>
                            </div>
                            <div class="detail-item">
                                <div class="detail-label">Дата и время</div>
                                <div class="detail-value">${new Date(mockData.dateTime).toLocaleString('ru-RU')}</div>
                            </div>
                            <div class="detail-item">
                                <div class="detail-label">Статус</div>
                                <div class="detail-value">
                                    <span class="status-badge status-completed">Завершена</span>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="details-section">
                        <h3>Игроки</h3>
                        <div class="participants-list">
                            ${mockData.players.map(player => `
                                <div class="participant-card">
                                    <div class="participant-info">
                                        <img src="${player.avatar}" alt="${player.name}" class="participant-avatar">
                                        <div class="participant-details">
                                            <div class="participant-name">${player.name}</div>
                                            <div class="participant-meta">
                                                <a href="tel:${player.phone}">${player.phone}</a>
                                                <a href="https://t.me/${player.telegram.substring(1)}" target="_blank">${player.telegram}</a>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="participant-actions">
                                        ${!player.hasReview ? `
                                            <button onclick="openReviewForm('${player.id}')" class="btn btn-outline">
                                                <i data-feather="message-square"></i>
                                                Оставить отзыв
                                            </button>
                                        ` : `
                                            <span class="badge badge-success">Отзыв оставлен</span>
                                        `}
                                    </div>
                                </div>
                            `).join('')}
                        </div>
                    </div>

                    <div class="details-section">
                        <h3>Зрители</h3>
                        <div class="participants-list">
                            ${mockData.spectators.map(spectator => `
                                <div class="participant-card">
                                    <div class="participant-info">
                                        <img src="${spectator.avatar}" alt="${spectator.name}" class="participant-avatar">
                                        <div class="participant-details">
                                            <div class="participant-name">${spectator.name}</div>
                                            <div class="participant-meta">
                                                <span class="ticket-badge">${spectator.ticket}</span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            `).join('')}
                        </div>
                    </div>
                </div>
            `);

            // Обновляем иконки
            feather.replace();
        }

        // Функция закрытия модального окна
        function closeGameDetails() {
            $('#gameDetailsModal').removeClass('active');
        }

        // Закрытие модального окна при клике вне его
        $(document).on('click', function(event) {
            const $modal = $('#gameDetailsModal');
            if ($(event.target).is($modal)) {
                closeGameDetails();
            }
        });

        // Функции для отображения отзывов
        function showReviews() {
            alert('Здесь будут показаны отзывы о пользователе');
        }

        function showGameReviews(gameId) {
            alert('Здесь будут показаны отзывы об игре ' + gameId);
        }
        
// Повторная инициализация иконок после загрузки DOM
$(document).ready(function() {
    feather.replace();
});